<template>
  <el-dialog
    v-diadrag
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="80px"
      class="l-mes"
    >
      <el-form-item label="零件号" prop="partNo">
        <el-input v-model="dataForm.partNo" placeholder="请选择零件">
          <el-button
            slot="append"
            icon="el-icon-search"
            @click="openPartDialog()"
          ></el-button>
        </el-input>
      </el-form-item>
      <el-form-item label="工序" prop="operationName">
        <el-input v-model="dataForm.operationName" placeholder="请选择工序">
          <el-button
            slot="append"
            icon="el-icon-search"
            @click="openOperationDialog()"
          ></el-button>
        </el-input>
      </el-form-item>
      <el-form-item label="检测标准" prop="standardName">
        <el-input v-model="dataForm.standardName" placeholder="请选择检测标准">
          <el-button
            slot="append"
            icon="el-icon-search"
            @click="openStandardDialog()"
          ></el-button>
        </el-input>
      </el-form-item>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
    <partDialog :currshowlist.sync="showPart" @listenToPartEvent="selectPart" />
    <operationDialog
      :currshowlist.sync="showOperate"
      @listenToOperationEvent="selectOperate"
    />
    <testStandardDialog
      :currshowlist.sync="showTestStandard"
      @listenToSelectTestStandardEvent="selectTestStandard"
    />
  </el-dialog>
</template>
<script>
import { addObj, putObj, getObj } from '@/api/quality/standardbind'
import partDialog from '@/views/common/part.vue'
import operationDialog from '@/views/common/operation.vue'
import testStandardDialog from '@/views/common/teststandardradio'
export default {
  components: {
    partDialog,
    operationDialog,
    testStandardDialog
  },
  data() {
    return {
      visible: false,
      dataForm: {
        id: 0,
        partId: null,
        partNo: null,
        partName: null,
        operationId: null,
        operationNo: null,
        operationName: null,
        standardId: null,
        standardNo: null,
        standardName: null
      },
      showPart: false,
      showOperate: false,
      showTestStandard: false,
      dataRule: {},
      isSubmit: false
    }
  },
  created() {},
  methods: {
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.initData()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },
    // 初始化dataForm数据
    initData() {
      this.dataForm.partId = null
      this.dataForm.partNo = null
      this.dataForm.partName = null
      this.dataForm.operationId = null
      this.dataForm.operationNo = null
      this.dataForm.operationName = null
      this.dataForm.standardId = null
      this.dataForm.standardNo = null
      this.dataForm.standardName = null
    },
    openPartDialog() {
      this.showPart = true
    },
    openOperationDialog() {
      this.showOperate = true
    },
    openStandardDialog() {
      this.showTestStandard = true
    },
    selectPart(param, nodePart, index) {
      console.log(param)
      if (param) {
        this.dataForm.partId = param.id
        this.dataForm.partNo = param.partNo
        this.dataForm.partName = param.partName
      }
    },
    selectOperate(operate) {
      console.log(operate)
      if (operate) {
        this.dataForm.operationId = operate.id
        this.dataForm.operationNo = operate.operationNo
        this.dataForm.operationName = operate.name
      }
    },
    selectTestStandard(param) {
      console.log(param)
      if (param) {
        this.dataForm.standardId = param.id
        this.dataForm.standardNo = param.standardNo
        this.dataForm.standardName = param.standardName
      }
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      if (this.dataForm.id) {
        putObj(this.dataForm).then((data) => {
          this.$message.success('修改成功')
          this.visible = false
          this.isSubmit = false
          this.$emit('refreshDataList')
        })
      } else {
        addObj(this.dataForm).then((data) => {
          this.$message.success('新增成功')
          this.visible = false
          this.isSubmit = false
          this.$emit('refreshDataList')
        })
      }
    }
  }
}
</script>
